==> jc-1.4.0.tar.gz: javax/naming/spi/DirectoryManager.h <==
// public class javax.naming.spi.DirectoryManager

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b340b437b34e3cbd javax_naming_spi_DirectoryManager
// @dep_class 15ea04e1d7da936f javax_naming_spi_NamingManager

// header file dependencies
// @dep_header javax_naming_spi_NamingManager

#include "javax/naming/spi/NamingManager.h"

#ifndef _JC_javax_naming_spi_DirectoryManager_H_
#define _JC_javax_naming_spi_DirectoryManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_CannotProceedException$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;
struct _jc_javax_naming_directory_Attributes$object;
struct _jc_javax_naming_directory_DirContext$object;
struct _jc_javax_naming_spi_DirStateFactory__24Result$object;
struct _jc_javax_naming_spi_ObjectFactory$object;

// Typedefs
typedef struct _jc_javax_naming_spi_DirectoryManager$sub_refs	_jc_javax_naming_spi_DirectoryManager$sub_refs;
typedef struct _jc_javax_naming_spi_DirectoryManager$sub_nonrefs	_jc_javax_naming_spi_DirectoryManager$sub_nonrefs;
typedef struct _jc_javax_naming_spi_DirectoryManager$refs	_jc_javax_naming_spi_DirectoryManager$refs;
typedef struct _jc_javax_naming_spi_DirectoryManager$nonrefs	_jc_javax_naming_spi_DirectoryManager$nonrefs;
typedef struct _jc_javax_naming_spi_DirectoryManager$object	_jc_javax_naming_spi_DirectoryManager$object;

typedef const struct _jc_javax_naming_spi_DirectoryManager$vmethods	_jc_javax_naming_spi_DirectoryManager$vmethods;
typedef const struct _jc_javax_naming_spi_DirectoryManager$vtable	_jc_javax_naming_spi_DirectoryManager$vtable;
typedef const struct _jc_javax_naming_spi_DirectoryManager$vtype	_jc_javax_naming_spi_DirectoryManager$vtype;

// Constructors
extern void _jc_javax_naming_spi_DirectoryManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_spi_DirectoryManager$object *);

// Static methods
extern struct _jc_object *_jc_javax_naming_spi_DirectoryManager$method$getContinuationDirContext$8bf0e0f4b5dfcb50(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirectoryManager$method$getObjectInstance$f5f417b4765e310a(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *);
extern struct _jc_javax_naming_spi_DirStateFactory__24Result$object *_jc_javax_naming_spi_DirectoryManager$method$getStateToBind$326a60e4d8104af1(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirectoryManager$method$tryCreateObject$6353889c4705a6bb(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *);

// Virtual methods structure
struct _jc_javax_naming_spi_DirectoryManager$vmethods {
};

// Vtable
struct _jc_javax_naming_spi_DirectoryManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_NamingManager$vmethods	javax_naming_spi_NamingManager;
	_jc_javax_naming_spi_DirectoryManager$vmethods	javax_naming_spi_DirectoryManager;
};

// Vtype
struct _jc_javax_naming_spi_DirectoryManager$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_DirectoryManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_DirectoryManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_DirectoryManager$refs {
    _jc_javax_naming_spi_DirectoryManager$sub_refs	javax_naming_spi_DirectoryManager;
    _jc_javax_naming_spi_NamingManager$sub_refs	javax_naming_spi_NamingManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_DirectoryManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_DirectoryManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_NamingManager$sub_nonrefs	javax_naming_spi_NamingManager;
    _jc_javax_naming_spi_DirectoryManager$sub_nonrefs	javax_naming_spi_DirectoryManager;
};

// Object instance structure
struct _jc_javax_naming_spi_DirectoryManager$object {
	_jc_javax_naming_spi_DirectoryManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_DirectoryManager$vtype	*vtype;
	_jc_javax_naming_spi_DirectoryManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_DirectoryManager$vtype _jc_javax_naming_spi_DirectoryManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_DirectoryManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_DirectoryManager$class_object;

#endif	/* _JC_javax_naming_spi_DirectoryManager_H_ */

==> jc-1.4.6.tar.gz: javax/naming/spi/DirectoryManager.h <==
// public class javax.naming.spi.DirectoryManager

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b340b437b34e3cbd javax_naming_spi_DirectoryManager
// @dep_class 15ea04e1d7da936f javax_naming_spi_NamingManager

// header file dependencies
// @dep_header javax_naming_spi_NamingManager

#include "javax/naming/spi/NamingManager.h"

#ifndef _JC_javax_naming_spi_DirectoryManager_H_
#define _JC_javax_naming_spi_DirectoryManager_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_CannotProceedException$object;
struct _jc_javax_naming_Context$object;
struct _jc_javax_naming_Name$object;
struct _jc_javax_naming_directory_Attributes$object;
struct _jc_javax_naming_directory_DirContext$object;
struct _jc_javax_naming_spi_DirStateFactory__24Result$object;
struct _jc_javax_naming_spi_ObjectFactory$object;

// Typedefs
typedef struct _jc_javax_naming_spi_DirectoryManager$sub_refs	_jc_javax_naming_spi_DirectoryManager$sub_refs;
typedef struct _jc_javax_naming_spi_DirectoryManager$sub_nonrefs	_jc_javax_naming_spi_DirectoryManager$sub_nonrefs;
typedef struct _jc_javax_naming_spi_DirectoryManager$refs	_jc_javax_naming_spi_DirectoryManager$refs;
typedef struct _jc_javax_naming_spi_DirectoryManager$nonrefs	_jc_javax_naming_spi_DirectoryManager$nonrefs;
typedef struct _jc_javax_naming_spi_DirectoryManager$object	_jc_javax_naming_spi_DirectoryManager$object;

typedef const struct _jc_javax_naming_spi_DirectoryManager$vmethods	_jc_javax_naming_spi_DirectoryManager$vmethods;
typedef const struct _jc_javax_naming_spi_DirectoryManager$vtable	_jc_javax_naming_spi_DirectoryManager$vtable;
typedef const struct _jc_javax_naming_spi_DirectoryManager$vtype	_jc_javax_naming_spi_DirectoryManager$vtype;

// Constructors
extern void _jc_javax_naming_spi_DirectoryManager$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_spi_DirectoryManager$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_naming_spi_DirectoryManager$method$getContinuationDirContext$8bf0e0f4b5dfcb50(_jc_env *, struct _jc_javax_naming_CannotProceedException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirectoryManager$method$getObjectInstance$f5f417b4765e310a(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_javax_naming_spi_DirStateFactory__24Result$object *_jc_javax_naming_spi_DirectoryManager$method$getStateToBind$326a60e4d8104af1(_jc_env *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_naming_spi_DirectoryManager$method$tryCreateObject$6353889c4705a6bb(_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_object *, struct _jc_java_util_Hashtable$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_naming_spi_DirectoryManager$vmethods {
};

// Vtable
struct _jc_javax_naming_spi_DirectoryManager$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_spi_NamingManager$vmethods	javax_naming_spi_NamingManager;
	_jc_javax_naming_spi_DirectoryManager$vmethods	javax_naming_spi_DirectoryManager;
};

// Vtype
struct _jc_javax_naming_spi_DirectoryManager$vtype {
	_jc_type			type;
	_jc_javax_naming_spi_DirectoryManager$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_spi_DirectoryManager$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_spi_DirectoryManager$refs {
    _jc_javax_naming_spi_DirectoryManager$sub_refs	javax_naming_spi_DirectoryManager;
    _jc_javax_naming_spi_NamingManager$sub_refs	javax_naming_spi_NamingManager;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_spi_DirectoryManager$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_spi_DirectoryManager$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_spi_NamingManager$sub_nonrefs	javax_naming_spi_NamingManager;
    _jc_javax_naming_spi_DirectoryManager$sub_nonrefs	javax_naming_spi_DirectoryManager;
};

// Object instance structure
struct _jc_javax_naming_spi_DirectoryManager$object {
	_jc_javax_naming_spi_DirectoryManager$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_spi_DirectoryManager$vtype	*vtype;
	_jc_javax_naming_spi_DirectoryManager$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_spi_DirectoryManager$vtype _jc_javax_naming_spi_DirectoryManager$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_spi_DirectoryManager, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_spi_DirectoryManager$class_object;

#endif	/* _JC_javax_naming_spi_DirectoryManager_H_ */
